@@ -204,9 +204,10 @@ optionUI <- function(id) {
 #' @importFrom data.table data.table .SD :=
 #' @importFrom labelled var_label<-
 #' @importFrom stats glm as.formula model.frame na.omit
-#' @importFrom epiDisplay regress.display
-#' @importFrom jstable LabelepiDisplay
 #' @importFrom purrr map_lgl
+#' @importFrom rvg dml
+#' @importFrom officer read_pptx add_slide ph_with ph_location
+#' @importFrom ggpubr as_ggplot
 
 
 kaplanModule <- function(input, output, session, data, data_label, data_varStruct = NULL, nfactor.limit = 10, design.survey = NULL, id.cluster = NULL,
@@ -643,8 +644,8 @@ kaplanModule <- function(input, output, session, data, data_label, data_varStruc
     tagList(
       column(4,
              selectizeInput(session$ns("file_ext"), "File extension (dpi = 300)",
-                            choices = c("jpg","pdf", "tiff", "svg", "emf"), multiple = F,
-                            selected = "jpg"
+                            choices = c("jpg","pdf", "tiff", "svg", "pptx"), multiple = F,
+                            selected = "pptx"
              )
       ),
       column(4,
@@ -682,10 +683,12 @@ kaplanModule <- function(input, output, session, data, data_label, data_varStruc
                        Sys.sleep(0.01)
                      }
 
-                     if (input$file_ext == "emf"){
-                       devEMF::emf(file, width = input$fig_width, height = input$fig_height, coordDPI = 300, emfPlus = F)
-                       graphics::plot(kmInput())
-                       grDevices::dev.off()
+                     if (input$file_ext == "pptx"){
+                       my_vec_graph <- rvg::dml(ggobj  = ggpubr::as_ggplot(kmInput()))
+                       doc <- officer::read_pptx()
+                       doc <- officer::add_slide(doc, layout = "Title and Content", master = "Office Theme")
+                       doc <- officer::ph_with(doc, my_vec_graph, location = officer::ph_location(width = input$fig_width, height = input$fig_height))
+                       print(doc, target = file)
 
                      } else{
                        ggsave(file, kmInput(), dpi = 300, units = "in", width = input$fig_width, height =input$fig_height)
